==> ejc-purchasingmanagement-api-3.0.0-20220913.074542-227-sources.jar: com/ejianc/business/purchasingmanagement/vo/MaterialAcceptanceVO.java <==
package com.ejianc.business.purchasingmanagement.vo;

import java.math.BigDecimal;

/**
 * @authoer:禹鹏杰
 * @createDate:2022/9/13
 * @description:
 */
public class MaterialAcceptanceVO {
    private Long materialId; // 原材类主键
    private String materialName; // 原材类名称
    private BigDecimal totalAmount; // 合计金额
    private BigDecimal acceptanceQuantity; // 验收数量
    private BigDecimal price; // 单价
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public BigDecimal getTotalAmount() {
        return totalAmount;
    }

    public void setTotalAmount(BigDecimal totalAmount) {
        this.totalAmount = totalAmount;
    }

    public BigDecimal getAcceptanceQuantity() {
        return acceptanceQuantity;
    }

    public void setAcceptanceQuantity(BigDecimal acceptanceQuantity) {
        this.acceptanceQuantity = acceptanceQuantity;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
}

==> ejc-purchasingmanagement-api-3.0.0-20220914.064421-229-sources.jar: com/ejianc/business/purchasingmanagement/vo/MaterialAcceptanceVO.java <==
package com.ejianc.business.purchasingmanagement.vo;

import java.math.BigDecimal;

/**
 * @authoer:禹鹏杰
 * @createDate:2022/9/13
 * @description:
 */
public class MaterialAcceptanceVO {
    private Long materialId; // 原材类主键
    private String materialName; // 原材类名称
    private BigDecimal amount; // 合计金额
    private BigDecimal acceptanceQuantity; // 验收数量
    private BigDecimal price; // 单价
    private Long orgId; // 所属组织id
    private String orgName; // 所属组织名称

    public Long getMaterialId() {
        return materialId;
    }

    public void setMaterialId(Long materialId) {
        this.materialId = materialId;
    }

    public String getMaterialName() {
        return materialName;
    }

    public void setMaterialName(String materialName) {
        this.materialName = materialName;
    }

    public BigDecimal getAmount() {
        return amount;
    }

    public void setAmount(BigDecimal amount) {
        this.amount = amount;
    }

    public BigDecimal getAcceptanceQuantity() {
        return acceptanceQuantity;
    }

    public void setAcceptanceQuantity(BigDecimal acceptanceQuantity) {
        this.acceptanceQuantity = acceptanceQuantity;
    }

    public BigDecimal getPrice() {
        return price;
    }

    public void setPrice(BigDecimal price) {
        this.price = price;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
}
